package com.sygem.swing.demos;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.sygem.swing.joutlooknavbar.*;
import com.sygem.swing.renderers.*;

/**
 * <p>Title: JOutlookNavBar</p>
 * <p>Description: A Swing component simulating Outlook's Nav Bar</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: SyGem Software</p>
 * @author Simon Jewell
 * @version 1.1b
 */

public class JOutlookNavBarDemoFrame extends JFrame {
  JPanel contentPane;
  JLabel statusBar = new JLabel();
  BorderLayout borderLayout1 = new BorderLayout();
  JPanel jPanel1 = new JPanel();
  JButton albumPropertiesButton = new JButton();
  JButton preferencesButton = new JButton();
  JButton transparencyButton = new JButton();

  //Construct the frame
  public JOutlookNavBarDemoFrame() {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
  }

  // Create the JOutlookNavBar
  JOutlookNavBar outlookBar = new JOutlookNavBar();

  // Now, create some categories
  NavBarCategory cat1 = new NavBarCategory("Projects");
  NavBarCategory cat2 = new NavBarCategory("Album Properties");
  NavBarCategory cat3 = new NavBarCategory("Image Operations");
  NavBarCategory cat4 = new NavBarCategory("Preferences");
  GridBagLayout gridBagLayout1 = new GridBagLayout();

  //Component initialization
  private void jbInit() throws Exception  {
    contentPane = (JPanel) this.getContentPane();
    contentPane.setLayout(borderLayout1);

    // Create the items for the Projects category
    NavBarItem newProjectItem = new NavBarItem("New Project");
    newProjectItem.setIcon(new ImageIcon(getClass().getResource("/images/newFile.gif")));
    newProjectItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("New project item selected...");
      }
    });
    NavBarItem openProjectItem = new NavBarItem("Open Project");
    openProjectItem.setIcon(new ImageIcon(getClass().getResource("/images/openFile.gif")));
    openProjectItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Open project item selected...");
      }
    });
    NavBarItem closeProjectItem = new NavBarItem("Close Project");
    closeProjectItem.setIcon(new ImageIcon(getClass().getResource("/images/closeFile.gif")));
    closeProjectItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Close project item selected...");
      }
    });
    NavBarItem deleteProjectItem = new NavBarItem("Delete Project");
    deleteProjectItem.setIcon(new ImageIcon(getClass().getResource("/images/deleteFile.gif")));
    deleteProjectItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Delete project item selected...");
      }
    });
    cat1.addItem(newProjectItem);
    cat1.addItem(openProjectItem);
    cat1.addItem(closeProjectItem);
    cat1.addItem(deleteProjectItem);
    cat1.setInsets(new Insets(0,3,0,3));
    cat1.setBackgroundRenderer(new GradientBackgroundRenderer(new Color(255,255,255),new Color(211,207,196)));

    // Create the items for the "Album Properties" category
    NavBarItem detailsItem = new NavBarItem("Details");
    detailsItem.setIcon(new ImageIcon(getClass().getResource("/images/details.gif")));
    detailsItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Details item selected...");
      }
    });
    NavBarItem printItem = new NavBarItem("Print Album");
    printItem.setIcon(new ImageIcon(getClass().getResource("/images/printer16.gif")));
    printItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Print Album item selected...");
      }
    });
    NavBarItem configItem = new NavBarItem("Configuration");
    configItem.setIcon(new ImageIcon(getClass().getResource("/images/configuration.gif")));
    configItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Configuration item selected...");
      }
    });
    NavBarItem previewItem = new NavBarItem("Preview Album");
    previewItem.setIcon(new ImageIcon(getClass().getResource("/images/preview.gif")));
    previewItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Preview Album item selected...");
      }
    });
    cat2.addItem(detailsItem);
    cat2.addItem(printItem);
    cat2.addItem(configItem);
    cat2.addItem(previewItem);
    cat2.setInsets(new Insets(0,3,0,3));
    cat2.setBackgroundRenderer(new GradientBackgroundRenderer(new Color(255,255,255),new Color(211,207,196)));

    // Create the items for the "Image Operations" category
    NavBarItem cropItem = new NavBarItem("Crop Images");
    cropItem.setIcon(new ImageIcon(getClass().getResource("/images/cropImages.gif")));
    cropItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Crop Images item selected...");
      }
    });
    NavBarItem fxItem = new NavBarItem("Apply Special FX");
    fxItem.setIcon(new ImageIcon(getClass().getResource("/images/fx16.gif")));
    fxItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Apply Special FX item selected...");
      }
    });
    NavBarItem addBordersItem = new NavBarItem("Add Borders");
    addBordersItem.setIcon(new ImageIcon(getClass().getResource("/images/addBorders.gif")));
    addBordersItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Add Borders item selected...");
      }
    });
    NavBarItem captionItem = new NavBarItem("Add Captions");
    captionItem.setIcon(new ImageIcon(getClass().getResource("/images/text16.gif")));
    captionItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Add Captions item selected...");
      }
    });
    NavBarItem webItem = new NavBarItem("Save For Web");
    webItem.setIcon(new ImageIcon(getClass().getResource("/images/save4Web.gif")));
    webItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Save 4 Web item selected...");
      }
    });
    cat3.addItem(cropItem);
    cat3.addItem(fxItem);
    cat3.addItem(addBordersItem);
    cat3.addItem(captionItem);
    cat3.addItem(webItem);
    cat3.setInsets(new Insets(0,3,0,3));
    cat3.setBackgroundRenderer(new GradientBackgroundRenderer(new Color(255,255,255),new Color(211,207,196)));

    // Create the items for the "Preferences" category
    NavBarItem interfaceItem = new NavBarItem("Interface");
    interfaceItem.setIcon(new ImageIcon(getClass().getResource("/images/PreferencesInterface.gif")));
    interfaceItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Interface Preferences item selected...");
      }
    });
    NavBarItem undoRedoItem = new NavBarItem("Undo / Redo");
    undoRedoItem.setIcon(new ImageIcon(getClass().getResource("/images/PreferencesUndoRedo.gif")));
    undoRedoItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Undo/Redo Preferences item selected...");
      }
    });
    NavBarItem fileFormatsItem = new NavBarItem("File Formats");
    fileFormatsItem.setIcon(new ImageIcon(getClass().getResource("/images/PreferencesFileFormats.gif")));
    fileFormatsItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("File Formats Preferences item selected...");
      }
    });
    NavBarItem zoomItem = new NavBarItem("Zoom Controls");
    zoomItem.setIcon(new ImageIcon(getClass().getResource("/images/PreferencesZoom.gif")));
    zoomItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Zoom Preferences item selected...");
      }
    });
    NavBarItem transparencyItem = new NavBarItem("Transparency");
    transparencyItem.setIcon(new ImageIcon(getClass().getResource("/images/PreferencesTransparency.gif")));
    transparencyItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Transparency Preferences item selected...");
      }
    });
    NavBarItem unitsItem = new NavBarItem("Units");
    unitsItem.setIcon(new ImageIcon(getClass().getResource("/images/PreferencesUnits.gif")));
    unitsItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Units Preferences item selected...");
      }
    });
    cat4.addItem(interfaceItem);
    cat4.addItem(undoRedoItem);
    cat4.addItem(fileFormatsItem);
    cat4.addItem(zoomItem);
    cat4.addItem(transparencyItem);
    cat4.addItem(unitsItem);
    cat4.setInsets(new Insets(0,3,0,3));
    cat4.setBackgroundRenderer(new GradientBackgroundRenderer(new Color(255,255,255),new Color(211,207,196)));

    outlookBar.getModel().addCategory(cat1);
    outlookBar.getModel().addCategory(cat2);
    outlookBar.getModel().addCategory(cat3);
    outlookBar.getModel().addCategory(cat4);

    //outlookBar.setAnimationDelay(50);

    albumPropertiesButton.setText("Album Properties");
    albumPropertiesButton.addActionListener(new JOutlookNavBarDemoFrame_albumPropertiesButton_actionAdapter(this));
    preferencesButton.setText("Preferences");
    preferencesButton.addActionListener(new JOutlookNavBarDemoFrame_preferencesButton_actionAdapter(this));
    transparencyButton.setText("Transparency");
    transparencyButton.addActionListener(new JOutlookNavBarDemoFrame_transparencyButton_actionAdapter(this));
    jPanel1.setDebugGraphicsOptions(0);
    jPanel1.setLayout(gridBagLayout1);
    contentPane.add(outlookBar, BorderLayout.WEST);

    this.setSize(new Dimension(400, 500));
    this.setTitle("JOutlookNavBar Demo");
    statusBar.setText("Ready...");
    contentPane.add(statusBar, BorderLayout.SOUTH);
    contentPane.add(jPanel1, BorderLayout.EAST);
    jPanel1.add(albumPropertiesButton,     new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 0, 5), 0, 0));
    jPanel1.add(preferencesButton,     new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 0, 5), 0, 0));
    jPanel1.add(transparencyButton,      new GridBagConstraints(0, 2, 1, 1, 0.0, 1.0
            ,GridBagConstraints.NORTH, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 0, 5), 0, 0));
  }

  //Overridden so we can exit when window is closed
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      System.exit(0);
    }
  }

  void transparencyButton_actionPerformed(ActionEvent e) {
    cat4.selectNavBarItem(cat4.getItem("Transparency"),true);
  }

  void preferencesButton_actionPerformed(ActionEvent e) {
    cat4.openCategory(false);
  }

  void albumPropertiesButton_actionPerformed(ActionEvent e) {
    cat2.openCategory(false);
  }
}

class JOutlookNavBarDemoFrame_transparencyButton_actionAdapter implements java.awt.event.ActionListener {
  JOutlookNavBarDemoFrame adaptee;

  JOutlookNavBarDemoFrame_transparencyButton_actionAdapter(JOutlookNavBarDemoFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.transparencyButton_actionPerformed(e);
  }
}

class JOutlookNavBarDemoFrame_preferencesButton_actionAdapter implements java.awt.event.ActionListener {
  JOutlookNavBarDemoFrame adaptee;

  JOutlookNavBarDemoFrame_preferencesButton_actionAdapter(JOutlookNavBarDemoFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.preferencesButton_actionPerformed(e);
  }
}

class JOutlookNavBarDemoFrame_albumPropertiesButton_actionAdapter implements java.awt.event.ActionListener {
  JOutlookNavBarDemoFrame adaptee;

  JOutlookNavBarDemoFrame_albumPropertiesButton_actionAdapter(JOutlookNavBarDemoFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.albumPropertiesButton_actionPerformed(e);
  }
}
